@@ -8,10 +8,12 @@ use routines;
 
 use parent 'Data::Object::Name';
 
-our $VERSION = '2.02'; # VERSION
+our $VERSION = '2.03'; # VERSION
 
 # METHODS
 
+my %has;
+
 method append(@args) {
   my $class = $self->class;
 
@@ -150,6 +152,20 @@ method cop($func, @args) {
   return sub { $next->(@args ? (@args, @_) : @_) };
 }
 
+method destroy() {
+  require Symbol;
+
+  Symbol::delete_package($self->package);
+
+  my $c_re = quotemeta $self->package;
+  my $p_re = quotemeta $self->path;
+
+  map {delete $has{$_}} grep /^$c_re/, keys %has;
+  map {delete $INC{$_}} grep /^$p_re/, keys %INC;
+
+  return $self;
+}
+
 method eval(@args) {
   local $@;
 
@@ -207,17 +223,15 @@ method inherits() {
   return $self->array('ISA');
 }
 
-method inc() {
+method included() {
 
   return $INC{$self->format('path', '%s.pm')};
 }
 
-my $loaded_spaces = {};
-
 method load() {
   my $class = $self->package;
 
-  return $class if $loaded_spaces->{$class};
+  return $class if $has{$class};
 
   my $failed = !$class || $class !~ /^\w(?:[\w:']*\w)?$/;
   my $loaded;
@@ -245,7 +259,7 @@ method load() {
   or $failed
   or not $loaded;
 
-  $loaded_spaces->{$class} = 1;
+  $has{$class} = 1;
 
   return $class;
 }
@@ -254,12 +268,24 @@ method loaded() {
   my $class = $self->package;
   my $pexpr = $self->format('path', '%s.pm');
 
-  my $is_loaded_eval = $loaded_spaces->{$class};
+  my $is_loaded_eval = $has{$class};
   my $is_loaded_used = $INC{$pexpr};
 
   return ($is_loaded_eval || $is_loaded_used) ? 1 : 0;
 }
 
+method locate() {
+  my $found = '';
+
+  my $file = $self->format('path', '%s.pm');
+
+  for my $path (@INC) {
+    do { $found = "$path/$file"; last } if -f "$path/$file";
+  }
+
+  return $found;
+}
+
 method methods() {
   my @methods;
 
@@ -317,6 +343,14 @@ method prepend(@args) {
   return $class->new($path);
 }
 
+method rebase(@args) {
+  my $class = $self->class;
+
+  my $path = join '/', map $class->new($_)->path, @args;
+
+  return $class->new($self->base)->prepend($path);
+}
+
 method root() {
 
   return $self->parse->[0];
@@ -400,16 +434,12 @@ method siblings() {
 
 method used() {
   my $class = $self->package;
-  my $loaded = $loaded_spaces->{$class};
   my $path = $self->path;
   my $regexp = quotemeta $path;
 
-  if ($loaded) {
+  return $path if $has{$class};
 
-    return $path;
-  }
   for my $item (keys %INC) {
-
     return $path if $item =~ /$regexp\.pm$/;
   }
 
@@ -809,6 +839,32 @@ and if successful returns a closure.
 
 =cut
 
+=head2 destroy
+
+  destroy() : Object
+
+The destroy method attempts to wipe out a namespace and also remove it and its
+children from C<%INC>. B<NOTE:> This can cause catastrophic failures if used
+incorrectly.
+
+=over 4
+
+=item destroy example #1
+
+  package main;
+
+  use Data::Object::Space;
+
+  my $space = Data::Object::Space->new('data/dumper');
+
+  $space->load; # Data/Dumper
+
+  $space->destroy;
+
+=back
+
+=cut
+
 =head2 eval
 
   eval(Str @args) : Any
@@ -946,21 +1002,21 @@ The id method returns the fully-qualified package name as a label.
 
 =cut
 
-=head2 inc
+=head2 included
 
-  inc() : Str
+  included() : Str
 
-The inc method returns the path of the namespace if it exists in C<%INC>.
+The included method returns the path of the namespace if it exists in C<%INC>.
 
 =over 4
 
-=item inc example #1
+=item included example #1
 
   package main;
 
   my $space = Data::Object::Space->new('Data/Object/Space');
 
-  $space->inc;
+  $space->included;
 
   # lib/Data/Object/Space.pm
 
@@ -1085,6 +1141,48 @@ returns truthy or falsy.
 
 =cut
 
+=head2 locate
+
+  locate() : Str
+
+The locate method checks whether the package namespace is available in
+C<@INC>, i.e. on disk. This method returns the file if found or an empty
+string.
+
+=over 4
+
+=item locate example #1
+
+  package main;
+
+  use Data::Object::Space;
+
+  my $space = Data::Object::Space->new('foo');
+
+  $space->locate;
+
+  # ''
+
+=back
+
+=over 4
+
+=item locate example #2
+
+  package main;
+
+  use Data::Object::Space;
+
+  my $space = Data::Object::Space->new('data/dumper');
+
+  $space->locate;
+
+  # /path/to/Data/Dumper.pm
+
+=back
+
+=cut
+
 =head2 methods
 
   methods() : ArrayRef
@@ -1307,6 +1405,27 @@ parts.
 
 =cut
 
+=head2 rebase
+
+  rebase(Str @args) : Object
+
+The rebase method returns an object by prepending the package namespace
+specified to the base of the current object's namespace.
+
+=over 4
+
+=item rebase example #1
+
+  # given: synopsis
+
+  $space->rebase('zoo');
+
+  # Zoo/Bar
+
+=back
+
+=cut
+
 =head2 root
 
   root() : Str
